@@ -14,4 +14,7 @@ from pyefun.progiterUtil import *
 from pyefun.stringUtil import *
 from pyefun.timeUtil import *
 
-__version__ = '1.0.10'
\ No newline at end of file
+from pyefun.threadingUtil import *
+from pyefun.networkUtil import *
+
+__version__ = '1.0.11'
\ No newline at end of file
